#
# spec file for package superlu
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Christoph Grüninger foss@grueninger.de
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           superlu
Summary:        A general purpose library for the direct solution of sparse systems of linear equations
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Version:        5.2.1
Release:        lp150.1.9
%define soname lib%{name}5
#Source:         http://crd-legacy.lbl.gov/~xiaoye/SuperLU/superlu_5.2.1.tar.gz
Source:         %{name}_%{version}-bsd.tar.gz
Source1:        superlu_ug.pdf
Source2:        README.SUSE
Source3:        baselibs.conf
# PATCH-FIX-UPSTREAM superlu-4.3-include.patch : avoid implicit declaration warnings
Patch1:         superlu-4.3-include.patch
# PATCH-FIX-UPSTREAM superlu-4.3-dont-opt-away.diff
Patch2:         superlu-4.3-dont-opt-away.diff
# PATCH-FIX-OPENSUSE superlu-5.2-remove-mc64ad.patch [bnc#796236] 
# The Harwell Subroutine Library (HSL) routine mc64ad.c have been removed
# from the original sources for legal reasons. This patch disables the inclusion of
# this routine in the library which, however, remains fully functionnal
Patch3:         superlu-5.2-remove-mc64ad.patch
Url:            http://crd.lbl.gov/~xiaoye/SuperLU/
BuildRequires:  blas-devel
BuildRequires:  cmake >= 2.8.12
BuildRequires:  fdupes
BuildRequires:  gcc-fortran
BuildRequires:  tcsh
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SuperLU is an algorithm that uses group theory to optimize LU
decomposition of sparse matrices.

%package -n %soname
Summary:        SuperLU matrix solver
Group:          System/Libraries

%description -n %soname
SuperLU is an algorithm that uses group theory to optimize LU
decomposition of sparse matrices.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %soname = %{version}
# The standalone superlu RPM has been eliminated, and the relevant
# files are now in superlu-devel
# The last standalone superlu RPM was was v3.0
Provides:       superlu = %{version}
Obsoletes:      superlu <= 3.0

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n SuperLU_%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
# superlu_ug.pdf in %%doc 
cp %SOURCE1 %SOURCE2 ./

%build
# FIXME: Drop the -Denable_tests=OFF flag when MATGEN linking issues are resolved
%cmake \
  -DCMAKE_BUILD_TYPE=Release -DUSE_XSDK_DEFAULTS='TRUE' -Denable_tests=OFF

make %{?_smp_mflags}
cd ..

%install
%cmake_install

#fix permissions
chmod 644 MATLAB/*

# remove all build examples
cd EXAMPLE
make clean
rm -rf *itersol*
cd ..
mv EXAMPLE examples
cp FORTRAN/README README.fortran
%fdupes -s examples

%check
ln -s examples/ EXAMPLE
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
make testing
echo -ne "\nTest results\n"
for i in stest dtest ctest ztest; do
    cat TESTING/$i.out
done

%post -n %soname -p /sbin/ldconfig

%postun -n %soname -p /sbin/ldconfig

%files -n %soname
%defattr(-,root,root,-)
%doc README MATLAB README.SUSE
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%doc DOC/html examples README.fortran superlu_ug.pdf
%{_includedir}/*.h
%{_libdir}/*.so

%changelog
* Tue Jun 14 2016 badshah400@gmail.com
- Use system blas by passing the cmake option
  - DUSE_XSDK_DEFAULTS='TRUE'.
- Disable building tests for now because they have linking issues.
- Use cmake macros wherever appropriate.
- A minimum of cmake >= 2.8.12 is required for building.
* Sun May 29 2016 foss@grueninger.de
- Update to SuperLU 5.2.1
- Switch to CMake as build-system
- Drop superlu-4.3-disable-hsl.patch as CMake is now used
- Update to latest SuperLU User Guide
- superlu-4.3.diff, superlu-4.3-remove-hsl.patch: removed
- superlu-5.2-remove-mc64ad.patch: new, routine was removed
* Wed Jul 29 2015 dimstar@opensuse.org
- Add baselibs.conf: build libsuperlu4-32bit, as needed by
  libarmadillo.
* Tue Jan 15 2013 scorot@free.fr
- repackage original source tarball in order to remove the
  HSL mc64ad routine that caonnt be redistributed bnc#796236
- add README.SUSE file in the %%%%doci in order to explain
  that change
* Tue Jan  8 2013 scorot@free.fr
- add patch superlu-4.3-disable-hsl.patch in order to disable HSL
  code from the library
- update patch superlu-4.3.diff so that test routines are run
  against the  shared library
- build tests routines in %%%%check section
* Tue Dec 18 2012 scorot@free.fr
- Update to SuperLU 4.3:
  * Remove recursive DFS for postordering elimination tree in
    sp_coletree.c (The nonrecursive routine nr_etdfs() was
    contributed by Cedric Doucet, CEDRAT Group, Meylan, France.)
  * Make supermatrix.h the same for all three libraries
  * Include an on-line HTML documentation for the source code
  * Corrected backward error BERR formula when a component of the
    RHS and the residual are exactly zero
  * Change parameter "delta" to genmmd() from 1 to 0 in get_perm_c
    remove "static" declaration in EXAMPLE/xlinsolx*.c
  * Include threshold-based incomplete factorization (ILU)
  * Removed the static global variables so that it is thread-safe.
  * Make superlu_options_t{} structure and enum constants the same
    for both superlu & superlu_dist.
  * Replace qsort by "quick select" (qselect) in ILU's secondary
    dropping.
  * Replace mc64ad.f by mc64ad.c using f2c.
  * Bug fixes in ilu_sdrop_row.c.
  * Bug fixes in xgsisx.c, so that when mc64 permutation is used
    in ILU, the right-hand side is permuted properly.
  * Add parameter #7 in sp_ienv(), setting as the maxsuper for ILU
    code (smaller than parameter #3).
  * Update Users Guide.
  * Update doxygen code documentation.
  * Fix a bug in ILU driver routine dgsisx.c, so that on return,
    the initial row permutation is combined with perm_r[] from
    partial pivoting.
  * Modify 2 ILU examples: EXAMPLE/ditersol.c, EXAMPLE/ditersol1.c
  * Update superlu_timer.c
- Remove unneeded patches
  + superlu-overflow.patch : Applied upstream
  + superlu-initialize.diff : Applied upstream
  + superlu-undef-code.diff : Applied upstream
- Updated patches
  + superlu-4.3.diff
  + superlu-4.3-include.patch
  + superlu-4.3-dont-opt-away.diff
- Build shared libraries
- Put shared libs and devel files in separate packages
- Use rpm macros instead of plain directory names
- Add %%%%ckeck
- Update documentation file %%%%source1 and put html and examples
  files in %%%%doc
- Spec file reformating
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Thu Jun 22 2006 ro@suse.de
- remove selfprovides
* Mon Mar 27 2006 garloff@suse.de
- superlu-undef-code.diff: Fix undefined code (#160443).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec 22 2005 garloff@suse.de
- Install header files into /usr/include/superlu/
- Update User Guide.
* Wed Dec 21 2005 garloff@suse.de
- Include EXAMPLE dir as documentation.
- Build as non-root.
- Nuke unused local vars referencing uninitialized vars.
* Wed Dec 21 2005 garloff@suse.de
- Update to SuperLU-3.0: [#133821]
  * Added "options" input argument and "stat" output argument
    for the driver routines
  * More Examples
  * Added a "symmetric mode" for (nearly) symmetric matrices
  * Better Fortran interface.
  * fixed a bug in the complex drivers sgssvx/zgssvx when the
    input matrix is stored in compressed row format.
  * prefixed the header files by "slu_".
  * Fixed a memory leak in get_perm_c() when bnz=0.
  * Changed "abs" to "fabs" in izmax1.
  * Upgraded COLAMD to the latest version (2.3).15
- Add various declarations and #include statements
- Trick compiler into not optimizing away a loop in our timing
  measurement.
* Fri Nov 25 2005 yxu@suse.de
- add missing function prototypes
* Tue Nov 15 2005 dmueller@suse.de
- avoid an endless loop during building (#133820)
* Mon May  9 2005 meissner@suse.de
- fixed 1 byte buffer overflows.
* Mon Dec 20 2004 garloff@suse.de
- Pass $(RPM_OPT_FLAGS) -Os -fPIC for files that don't need to be
  optimized.
* Sat Sep  6 2003 garloff@suse.de
- Add -fPIC to allow inclusion in dynamic lib.
* Sun Aug 10 2003 garloff@suse.de
- -O3 leads to an endless loop in dlamanch test on x86. Probably
  some compiler of FPU weirdness. Remove -O3 on x86 again.
* Thu Aug  7 2003 garloff@suse.de
- Adapt chown syntax to owner:group.
- Reenable -O3 (compiler bug fixed?), but limit automatical
  inlining.
* Wed Jun 18 2003 ro@suse.de
- added directory to filelist.
* Wed Aug 28 2002 ro@suse.de
- remove -O3 from cflags (results in endless loop).
* Wed May  8 2002 garloff@suse.de
- lib64 fix.
* Wed May  8 2002 garloff@suse.de
- Fix test scripts.
- Use BuildRoot.
* Wed May  8 2002 garloff@suse.de
- Remove BLAS, Lapack.
- Rename package into SuperLU.
* Sat Apr 20 2002 garloff@suse.de
- Disable -fast-math
- In SuperLU, use CBLAS that ships with it
* Fri Apr 19 2002 garloff@suse.de
- Update to
  * CLAPACK-3.0
  * SuperLU-2.0
- Added SuperLU user guide
* Fri Apr 19 2002 garloff@suse.de
- Fixed compilation with gcc-3.1:
  link with -lfrtbegin (which contains main formerly in g2c)
* Tue Apr  9 2002 ro@suse.de
- fix owner for README.SuperLU
* Mon Aug  7 2000 garloff@suse.de
- Use %%{_docdir} to put docu in the right place.
* Mon Aug  7 2000 garloff@suse.de
- Add -mcpu=pentiumpro for i386
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Aug 31 1999 garloff@suse.de
- First creation of package.
